<?php
namespace Ems\portalGestor\Controller;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

use Ems\portalGestor\Service\SolicitacaoService;

class SolicitacaoController {
    /** @var EntityManager */
    protected $entityManager;

    /** @var SolicitacaoService */
    protected $solicitacaoService;

    public function __construct(
        EntityManager $entityManager,
        SolicitacaoService $solicitacaoService
    ) {
        $this->entityManager        = $entityManager;
        $this->solicitacaoService   = $solicitacaoService;
    }


    public function getSolicitacoesVinculosGestor(
        Request\Filter $request,
        Response       $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg        = (int) $row['NRORG'];
            $nrEstrutura  = (int) $row['NRESTRUTURAM'];

            $solicitacoes = $this->solicitacaoService->getSolicitacoesVinculosGestor(
                $nrOrg,
                $nrEstrutura
            );

            $response->addDataSet(new DataSet('data', $solicitacoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getItemSolicitacao(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];
            $nrsolicitacao         = $params['NRSOLICITACAO'];

            $dataSet = $this->solicitacaoService->getItemSolicitacao($nrOrg, $nrsolicitacao);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function getTiposolicitacao(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];

            $dataSet = $this->solicitacaoService->getTiposolicitacao($nrOrg);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getTpAvisoPrevio(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];

            $dataSet = $this->solicitacaoService->getTpAvisoPrevio($nrOrg);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getTpDemissao(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];

            $dataSet = $this->solicitacaoService->getTpDemissao($nrOrg);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getMotivoResc(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];

            $dataSet = $this->solicitacaoService->getMotivoResc($nrOrg);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function getMotivoOcupa(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];

            $dataSet = $this->solicitacaoService->getMotivoOcupa($nrOrg);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function getOcupacao(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];

            $dataSet = $this->solicitacaoService->getOcupacao($nrOrg);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getModalidadeSalarial(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];

            $dataSet = $this->solicitacaoService->getModalidadeSalarial($nrOrg);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function getTipoAlteraSal(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];

            $dataSet = $this->solicitacaoService->getTipoAlteraSal($nrOrg);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function getUltimoSalario(DTO\Request\Filter $request, Response $response) {
        try {
            $params = $request->getParameters();
            $nrOrg             = $params['NRORG'];
            $nrvinculo             = $params['NRVINCULOM'];

            $dataSet = $this->solicitacaoService->getUltimoSalario($nrOrg,$nrvinculo);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function solicitaAlteracao(DTO\Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            
            $success = $this->solicitacaoService->solicitaAlteracao($row);
            $response->addDataSet(new DataSet('data', array('success' => $success)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getTipoRelacionamento(
        Request\Filter $request,
        Response       $response
        ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];

            $tiposRel = $this->solicitacaoService->getTipoRelacionamento($nrOrg);

            $response->addDataSet(new DataSet('data', $tiposRel));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getLinhaTransporteAtiva(
        Request\Filter $request,
        Response       $response
        ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];

            $linhas = $this->solicitacaoService->getLinhaTransporteAtiva($nrOrg);

            $response->addDataSet(new DataSet('data', $linhas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getTipolinhavinc(
        Request\Filter $request,
        Response       $response
        ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];

            $tiposLinhas = $this->solicitacaoService->getTipolinhavinc($nrOrg);

            $response->addDataSet(new DataSet('data', $tiposLinhas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getIntegtransp(
        Request\Filter $request,
        Response       $response
        ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];

            $numerosIntegracao = $this->solicitacaoService->getIntegtransp($nrOrg);

            $response->addDataSet(new DataSet('data', $numerosIntegracao));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getSentidolinha(
        Request\Filter $request,
        Response       $response
        ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];

            $sentidos = $this->solicitacaoService->getSentidolinha($nrOrg);

            $response->addDataSet(new DataSet('data', $sentidos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getBeneficio(
        Request\Filter $request,
        Response       $response
        ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];

            $beneficios = $this->solicitacaoService->getBeneficio($nrOrg);

            $response->addDataSet(new DataSet('data', $beneficios));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getPessoaRelacionamentos(
        Request\Filter $request,
        Response       $response
        ) {
        try {
            $row = $request->getParameters();

            $nrOrg =    (int) $row['NRORG'];
            $nrPessoa = (int) $row['NRPESSOA'];

            $pessoas = $this->solicitacaoService->getPessoaRelacionamentos(
                $nrOrg, $nrPessoa
            );

            $response->addDataSet(new DataSet('data', $pessoas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
}